@@ -105,11 +105,11 @@ model{
  L[ntrt,ntrt] <- prod(sin(psi[ntrt-1,1:(ntrt-1)]))
  for(i in 1:(ntrt - 1)){
   for(j in 1:(ntrt - 1)){
-   psi[i, j] ~ dunif(0, 3.1415926)
+   psi[i, j] ~ dunif(0.01, 3.13)
   }
  }
  for(i in 1:ntrt){
-  sigma[i] ~ dunif(0, c)
+  sigma[i] ~ dunif(0.0001, c)
  }
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
@@ -170,11 +170,11 @@ model{
  L[ntrt,ntrt] <- prod(sin(psi[ntrt-1,1:(ntrt-1)]))
  for(i in 1:(ntrt - 1)){
   for(j in 1:(ntrt - 1)){
-   psi[i, j] ~ dunif(0, 3.1415926)
+   psi[i, j] ~ dunif(0.01, 3.13)
   }
  }
  for(i in 1:ntrt){
-  sigma[i] ~ dunif(0, c)
+  sigma[i] ~ dunif(0.0001, c)
  }
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
