@@ -12,7 +12,7 @@ model{
  for(j in 1:ntrt){
   AR[j]<-phi(mu[j]/sqrt(1+pow(sigma[j],2)))
   mu[j]~dnorm(0,0.001)
-  sigma[j]~dunif(0,c)
+  sigma[j]~dunif(0.0001,c)
  }
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
@@ -21,7 +21,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -52,7 +52,7 @@ model{
  for(j in 1:ntrt){
   AR[j]<-phi(mu[j]/sqrt(1+pow(sigma[j],2)))
   mu[j]~dnorm(0,0.001)
-  sigma[j]~dunif(0,c)
+  sigma[j]~dunif(0.0001,c)
  }
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
@@ -61,7 +61,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -98,7 +98,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -139,7 +139,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
