@@ -13,7 +13,7 @@ model{
   AR[j]<-phi(mu[j]/sqrt(1+pow(sigma,2)))
   mu[j]~dnorm(0,0.001)
  }
- sigma~dunif(0,c)
+ sigma~dunif(0.0001,c)
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
    T[j,k]<-1/sigma^2*ifelse(j==k,diag,offdiag)
@@ -21,7 +21,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -53,7 +53,7 @@ model{
   AR[j]<-phi(mu[j]/sqrt(1+pow(sigma,2)))
   mu[j]~dnorm(0,0.001)
  }
- sigma~dunif(0,c)
+ sigma~dunif(0.0001,c)
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
    T[j,k]<-1/sigma^2*ifelse(j==k,diag,offdiag)
@@ -61,7 +61,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -98,7 +98,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
@@ -139,7 +139,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){
   for(k in 1:ntrt){
    LRR[j,k]<-log(RR[j,k])
