@@ -14,7 +14,7 @@ model{
   rate[j]<-exp(mu[j]+pow(sigma[j],2)/2)
   lograte[j]<-log(rate[j])
   mu[j]~dnorm(0,0.001)
-  sigma[j]~dunif(0,c)
+  sigma[j]~dunif(0.0001,c)
  }
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
@@ -23,7 +23,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
    ratio[j,k]<-rate[j]/rate[k]
@@ -53,7 +53,7 @@ model{
   rate[j]<-exp(mu[j]+pow(sigma[j],2)/2)
   lograte[j]<-log(rate[j])
   mu[j]~dnorm(0,0.001)
-  sigma[j]~dunif(0,c)
+  sigma[j]~dunif(0.0001,c)
  }
  for(j in 1:ntrt){
   for(k in 1:ntrt){ 
@@ -62,7 +62,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
    ratio[j,k]<-rate[j]/rate[k]
@@ -98,7 +98,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
    ratio[j,k]<-rate[j]/rate[k]
@@ -138,7 +138,7 @@ model{
  }
  diag<-(1+(ntrt-2)*rho)/(1+(ntrt-2)*rho-(ntrt-1)*rho^2)
  offdiag<-(-rho/(1+(ntrt-2)*rho-(ntrt-1)*rho^2))
- rho~dunif(-1/(ntrt-1),1)
+ rho~dunif(-1/(ntrt-1),0.9999)
  for(j in 1:ntrt){        
   for(k in 1:ntrt){
    ratio[j,k]<-rate[j]/rate[k]
